# PHP Compatibility Scanner for Drupal 10

A lightweight Drupal 10 module that scans your modules for PHP compatibility issues before upgrading PHP versions.

## Overview

PHP Compatibility Scanner helps you identify potential problems in your code when planning to upgrade to a newer PHP version. It uses industry-standard tools (PHP_CodeSniffer with PHPCompatibility) to analyze your contributed and custom modules.

This module automatically detects your current PHP version and scans for compatibility with the next version (e.g., from PHP 8.1 to PHP 8.2).

## Features

- **Simple one-click scanning** - No configuration required
- **Automatic PHP version detection** - Knows your current version
- **Target version selection** - Choose which PHP version to check against
- **Batch processing** - Handles sites with many modules efficiently
- **Detailed issue reporting** - Shows file, line number, and issue description
- **Module categorization** - Separate results for contrib and custom modules
- **Classification by severity** - Distinguishes between errors and warnings

## Requirements

- Drupal 10.x
- PHP 7.4+ (recommended 8.0+)
- [PHP_CodeSniffer](https://github.com/squizlabs/PHP_CodeSniffer)
- [PHPCompatibility](https://github.com/PHPCompatibility/PHPCompatibility) standard

## Installation

1. Install via Composer (this will install all dependencies):
   ```bash
   composer require drupal/php_compatibility_scanner
   ```

2. Enable the module:
   ```bash
   drush en php_compatibility_scanner
   ```

## Usage

1. Navigate to **Reports → PHP Compatibility Scanner** (`/admin/reports/php-compatibility`)
2. Select which module types to scan (contributed and/or custom)
3. The system automatically detects your current PHP version and targets the next version
4. Click "Run Compatibility Scan"
5. Review the results showing compatibility issues
6. Click "View Issues" for detailed information about specific modules

## What It Scans For

- **Deprecated PHP functions** - Functions that will be removed in future versions
- **Removed PHP features** - Functionality already removed in the target version
- **Syntax changes** - Language syntax that has changed between PHP versions
- **Dynamic properties** - Property creation that's deprecated in PHP 8.2+
- **Other compatibility issues** - Various compatibility problems detected by PHPCompatibility

## How It Works

The module uses the [PHPCompatibility](https://github.com/PHPCompatibility/PHPCompatibility) ruleset for PHP_CodeSniffer to analyze the code in your Drupal modules. It provides comprehensive detection of compatibility issues across PHP versions.

## Performance

The module uses Drupal's Batch API to process modules one at a time, preventing timeouts on sites with many modules. Each module is scanned independently with proper memory management.

## Permissions

Users need the **"Administer site configuration"** permission to run scans.

## Troubleshooting

### "PHPCompatibility standard not found"
Install the missing dependency:
```bash
composer require phpcompatibility/php-compatibility:dev-develop dealerdirect/phpcodesniffer-composer-installer
```

### Scan timeout issues
The module uses batch processing to prevent timeouts, but very large modules might still cause issues. Consider increasing PHP memory limit or scanning module types separately.

## License

This project is licensed under the [GNU General Public License v2.0 or later](LICENSE).
