<?php

namespace Drupal\Tests\php_compatibility_scanner\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the PHP Compatibility Scanner functionality.
 *
 * @group php_compatibility_scanner
 */
class PhpCompatibilityScannerTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['php_compatibility_scanner'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with permission to administer the module.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser([
      'administer site configuration',
    ]);
  }

  /**
   * Test that the scanner page loads correctly.
   */
  public function testScannerPageLoad() {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('/admin/reports/php-compatibility');
    
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('PHP Compatibility Scanner');
    $this->assertSession()->pageTextContains('Current PHP Version');
    $this->assertSession()->fieldExists('scan_contrib');
    $this->assertSession()->fieldExists('scan_custom');
    $this->assertSession()->buttonExists('Run Compatibility Scan');
  }

  /**
   * Test form validation requires at least one module type.
   */
  public function testFormValidation() {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('/admin/reports/php-compatibility');
    
    // Submit form without selecting any module types
    $edit = [
      'scan_contrib' => FALSE,
      'scan_custom' => FALSE,
    ];
    $this->submitForm($edit, 'Run Compatibility Scan');
    
    $this->assertSession()->pageTextContains('Please select at least one module type to scan');
  }

  /**
   * Test access control.
   */
  public function testAccessControl() {
    // Anonymous user should be denied
    $this->drupalGet('/admin/reports/php-compatibility');
    $this->assertSession()->statusCodeEquals(403);
    
    // User without permission should be denied
    $user = $this->drupalCreateUser(['access content']);
    $this->drupalLogin($user);
    $this->drupalGet('/admin/reports/php-compatibility');
    $this->assertSession()->statusCodeEquals(403);
  }

}
